
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include <ModemManager.h>
#include "mm-errors-types.h"
/* enumerations from "../ModemManager/include/ModemManager-errors.h" */

/* mm_core_error_quark() implemented in mm-errors-quarks.c */

GType
mm_core_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_CORE_ERROR_FAILED, "MM_CORE_ERROR_FAILED", "Failed" },
        { MM_CORE_ERROR_CANCELLED, "MM_CORE_ERROR_CANCELLED", "Cancelled" },
        { MM_CORE_ERROR_ABORTED, "MM_CORE_ERROR_ABORTED", "Aborted" },
        { MM_CORE_ERROR_UNSUPPORTED, "MM_CORE_ERROR_UNSUPPORTED", "Unsupported" },
        { MM_CORE_ERROR_NO_PLUGINS, "MM_CORE_ERROR_NO_PLUGINS", "NoPlugins" },
        { MM_CORE_ERROR_UNAUTHORIZED, "MM_CORE_ERROR_UNAUTHORIZED", "Unauthorized" },
        { MM_CORE_ERROR_INVALID_ARGS, "MM_CORE_ERROR_INVALID_ARGS", "InvalidArgs" },
        { MM_CORE_ERROR_IN_PROGRESS, "MM_CORE_ERROR_IN_PROGRESS", "InProgress" },
        { MM_CORE_ERROR_WRONG_STATE, "MM_CORE_ERROR_WRONG_STATE", "WrongState" },
        { MM_CORE_ERROR_CONNECTED, "MM_CORE_ERROR_CONNECTED", "Connected" },
        { MM_CORE_ERROR_TOO_MANY, "MM_CORE_ERROR_TOO_MANY", "TooMany" },
        { MM_CORE_ERROR_NOT_FOUND, "MM_CORE_ERROR_NOT_FOUND", "NotFound" },
        { MM_CORE_ERROR_RETRY, "MM_CORE_ERROR_RETRY", "Retry" },
        { MM_CORE_ERROR_EXISTS, "MM_CORE_ERROR_EXISTS", "Exists" },
        { MM_CORE_ERROR_WRONG_SIM_STATE, "MM_CORE_ERROR_WRONG_SIM_STATE", "WrongSimState" },
        { MM_CORE_ERROR_RESET_AND_RETRY, "MM_CORE_ERROR_RESET_AND_RETRY", "ResetRetry" },
        { MM_CORE_ERROR_TIMEOUT, "MM_CORE_ERROR_TIMEOUT", "Timeout" },
        { MM_CORE_ERROR_PROTOCOL, "MM_CORE_ERROR_PROTOCOL", "Protocol" },
        { MM_CORE_ERROR_THROTTLED, "MM_CORE_ERROR_THROTTLED", "Throttled" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMCoreError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_mobile_equipment_error_quark() implemented in mm-errors-quarks.c */

GType
mm_mobile_equipment_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_MOBILE_EQUIPMENT_ERROR_PHONE_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_PHONE_FAILURE", "PhoneFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_NO_CONNECTION, "MM_MOBILE_EQUIPMENT_ERROR_NO_CONNECTION", "NoConnection" },
        { MM_MOBILE_EQUIPMENT_ERROR_LINK_RESERVED, "MM_MOBILE_EQUIPMENT_ERROR_LINK_RESERVED", "LinkReserved" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED", "NotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_NOT_SUPPORTED", "NotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_PH_SIM_PIN, "MM_MOBILE_EQUIPMENT_ERROR_PH_SIM_PIN", "PhSimPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_PH_FSIM_PIN, "MM_MOBILE_EQUIPMENT_ERROR_PH_FSIM_PIN", "PhFsimPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_PH_FSIM_PUK, "MM_MOBILE_EQUIPMENT_ERROR_PH_FSIM_PUK", "PhFsimPuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_NOT_INSERTED, "MM_MOBILE_EQUIPMENT_ERROR_SIM_NOT_INSERTED", "SimNotInserted" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_PIN, "MM_MOBILE_EQUIPMENT_ERROR_SIM_PIN", "SimPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_PUK, "MM_MOBILE_EQUIPMENT_ERROR_SIM_PUK", "SimPuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_SIM_FAILURE", "SimFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_BUSY, "MM_MOBILE_EQUIPMENT_ERROR_SIM_BUSY", "SimBusy" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_WRONG, "MM_MOBILE_EQUIPMENT_ERROR_SIM_WRONG", "SimWrong" },
        { MM_MOBILE_EQUIPMENT_ERROR_INCORRECT_PASSWORD, "MM_MOBILE_EQUIPMENT_ERROR_INCORRECT_PASSWORD", "IncorrectPassword" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_PIN2, "MM_MOBILE_EQUIPMENT_ERROR_SIM_PIN2", "SimPin2" },
        { MM_MOBILE_EQUIPMENT_ERROR_SIM_PUK2, "MM_MOBILE_EQUIPMENT_ERROR_SIM_PUK2", "SimPuk2" },
        { MM_MOBILE_EQUIPMENT_ERROR_MEMORY_FULL, "MM_MOBILE_EQUIPMENT_ERROR_MEMORY_FULL", "MemoryFull" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_INDEX, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_INDEX", "InvalidIndex" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_FOUND, "MM_MOBILE_EQUIPMENT_ERROR_NOT_FOUND", "NotFound" },
        { MM_MOBILE_EQUIPMENT_ERROR_MEMORY_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_MEMORY_FAILURE", "MemoryFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_TEXT_TOO_LONG, "MM_MOBILE_EQUIPMENT_ERROR_TEXT_TOO_LONG", "TextTooLong" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_CHARS, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_CHARS", "InvalidChars" },
        { MM_MOBILE_EQUIPMENT_ERROR_DIAL_STRING_TOO_LONG, "MM_MOBILE_EQUIPMENT_ERROR_DIAL_STRING_TOO_LONG", "DialStringTooLong" },
        { MM_MOBILE_EQUIPMENT_ERROR_DIAL_STRING_INVALID, "MM_MOBILE_EQUIPMENT_ERROR_DIAL_STRING_INVALID", "DialStringInvalid" },
        { MM_MOBILE_EQUIPMENT_ERROR_NO_NETWORK, "MM_MOBILE_EQUIPMENT_ERROR_NO_NETWORK", "NoNetwork" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_TIMEOUT, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_TIMEOUT", "NetworkTimeout" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_NOT_ALLOWED", "NetworkNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_PIN, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_PIN", "NetworkPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_PUK, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_PUK", "NetworkPuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_SUBSET_PIN, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_SUBSET_PIN", "NetworkSubsetPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_SUBSET_PUK, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_SUBSET_PUK", "NetworkSubsetPuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_PIN, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_PIN", "ServicePin" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_PUK, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_PUK", "ServicePuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_CORP_PIN, "MM_MOBILE_EQUIPMENT_ERROR_CORP_PIN", "CorpPin" },
        { MM_MOBILE_EQUIPMENT_ERROR_CORP_PUK, "MM_MOBILE_EQUIPMENT_ERROR_CORP_PUK", "CorpPuk" },
        { MM_MOBILE_EQUIPMENT_ERROR_HIDDEN_KEY_REQUIRED, "MM_MOBILE_EQUIPMENT_ERROR_HIDDEN_KEY_REQUIRED", "HiddenKeyRequired" },
        { MM_MOBILE_EQUIPMENT_ERROR_EAP_METHOD_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_EAP_METHOD_NOT_SUPPORTED", "EapMethodNotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_INCORRECT_PARAMETERS, "MM_MOBILE_EQUIPMENT_ERROR_INCORRECT_PARAMETERS", "IncorrectParameters" },
        { MM_MOBILE_EQUIPMENT_ERROR_COMMAND_DISABLED, "MM_MOBILE_EQUIPMENT_ERROR_COMMAND_DISABLED", "CommandDisabled" },
        { MM_MOBILE_EQUIPMENT_ERROR_COMMAND_ABORTED, "MM_MOBILE_EQUIPMENT_ERROR_COMMAND_ABORTED", "CommandAborted" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_ATTACHED_RESTRICTED, "MM_MOBILE_EQUIPMENT_ERROR_NOT_ATTACHED_RESTRICTED", "NotAttachedRestricted" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED_EMERGENCY_ONLY, "MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED_EMERGENCY_ONLY", "NotAllowedEmergencyOnly" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED_RESTRICTED, "MM_MOBILE_EQUIPMENT_ERROR_NOT_ALLOWED_RESTRICTED", "NotAllowedRestricted" },
        { MM_MOBILE_EQUIPMENT_ERROR_FIXED_DIAL_NUMBER_ONLY, "MM_MOBILE_EQUIPMENT_ERROR_FIXED_DIAL_NUMBER_ONLY", "FixedDialNumberOnly" },
        { MM_MOBILE_EQUIPMENT_ERROR_TEMPORARILY_OUT_OF_SERVICE, "MM_MOBILE_EQUIPMENT_ERROR_TEMPORARILY_OUT_OF_SERVICE", "TemporarilyOutOfService" },
        { MM_MOBILE_EQUIPMENT_ERROR_LANGUAGE_OR_ALPHABET_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_LANGUAGE_OR_ALPHABET_NOT_SUPPORTED", "LanguageOrAlphabetNotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNEXPECTED_DATA_VALUE, "MM_MOBILE_EQUIPMENT_ERROR_UNEXPECTED_DATA_VALUE", "UnexpectedDataValue" },
        { MM_MOBILE_EQUIPMENT_ERROR_SYSTEM_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_SYSTEM_FAILURE", "SystemFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_DATA_MISSING, "MM_MOBILE_EQUIPMENT_ERROR_DATA_MISSING", "DataMissing" },
        { MM_MOBILE_EQUIPMENT_ERROR_CALL_BARRED, "MM_MOBILE_EQUIPMENT_ERROR_CALL_BARRED", "CallBarred" },
        { MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_WAITING_INDICATION_SUBSCRIPTION_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_WAITING_INDICATION_SUBSCRIPTION_FAILURE", "MessageWaitingIndicationSubscriptionFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN, "MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN", "Unknown" },
        { MM_MOBILE_EQUIPMENT_ERROR_IMSI_UNKNOWN_IN_HSS, "MM_MOBILE_EQUIPMENT_ERROR_IMSI_UNKNOWN_IN_HSS", "ImsiUnknownInHss" },
        { MM_MOBILE_EQUIPMENT_ERROR_ILLEGAL_UE, "MM_MOBILE_EQUIPMENT_ERROR_ILLEGAL_UE", "IllegalUe" },
        { MM_MOBILE_EQUIPMENT_ERROR_IMSI_UNKNOWN_IN_VLR, "MM_MOBILE_EQUIPMENT_ERROR_IMSI_UNKNOWN_IN_VLR", "ImsiUnknownInVlr" },
        { MM_MOBILE_EQUIPMENT_ERROR_IMEI_NOT_ACCEPTED, "MM_MOBILE_EQUIPMENT_ERROR_IMEI_NOT_ACCEPTED", "ImeiNotAccepted" },
        { MM_MOBILE_EQUIPMENT_ERROR_ILLEGAL_ME, "MM_MOBILE_EQUIPMENT_ERROR_ILLEGAL_ME", "IllegalMe" },
        { MM_MOBILE_EQUIPMENT_ERROR_PS_SERVICES_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_PS_SERVICES_NOT_ALLOWED", "PsServicesNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_PS_AND_NON_PS_SERVICES_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_PS_AND_NON_PS_SERVICES_NOT_ALLOWED", "PsAndNonPsServicesNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_UE_IDENTITY_NOT_DERIVED_FROM_NETWORK, "MM_MOBILE_EQUIPMENT_ERROR_UE_IDENTITY_NOT_DERIVED_FROM_NETWORK", "UeIdentityNotDerivedFromNetwork" },
        { MM_MOBILE_EQUIPMENT_ERROR_IMPLICITLY_DETACHED, "MM_MOBILE_EQUIPMENT_ERROR_IMPLICITLY_DETACHED", "ImplicitlyDetached" },
        { MM_MOBILE_EQUIPMENT_ERROR_PLMN_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_PLMN_NOT_ALLOWED", "PlmnNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_AREA_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_AREA_NOT_ALLOWED", "AreaNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_ROAMING_NOT_ALLOWED_IN_AREA, "MM_MOBILE_EQUIPMENT_ERROR_ROAMING_NOT_ALLOWED_IN_AREA", "RoamingNotAllowedInArea" },
        { MM_MOBILE_EQUIPMENT_ERROR_PS_SERVICES_NOT_ALLOWED_IN_PLMN, "MM_MOBILE_EQUIPMENT_ERROR_PS_SERVICES_NOT_ALLOWED_IN_PLMN", "PsServicesNotAllowedInPlmn" },
        { MM_MOBILE_EQUIPMENT_ERROR_NO_CELLS_IN_AREA, "MM_MOBILE_EQUIPMENT_ERROR_NO_CELLS_IN_AREA", "NoCellsInArea" },
        { MM_MOBILE_EQUIPMENT_ERROR_MSC_TEMPORARILY_NOT_REACHABLE, "MM_MOBILE_EQUIPMENT_ERROR_MSC_TEMPORARILY_NOT_REACHABLE", "MscTemporarilyNotReachable" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_FAILURE_ATTACH, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_FAILURE_ATTACH", "NetworkFailureAttach" },
        { MM_MOBILE_EQUIPMENT_ERROR_CS_DOMAIN_UNAVAILABLE, "MM_MOBILE_EQUIPMENT_ERROR_CS_DOMAIN_UNAVAILABLE", "CsDomainUnavailable" },
        { MM_MOBILE_EQUIPMENT_ERROR_ESM_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_ESM_FAILURE", "EsmFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_CONGESTION, "MM_MOBILE_EQUIPMENT_ERROR_CONGESTION", "Congestion" },
        { MM_MOBILE_EQUIPMENT_ERROR_MBMS_BEARER_CAPABILITIES_INSUFFICIENT_FOR_SERVICE, "MM_MOBILE_EQUIPMENT_ERROR_MBMS_BEARER_CAPABILITIES_INSUFFICIENT_FOR_SERVICE", "MbmsBearerCapabilitiesInsufficientForService" },
        { MM_MOBILE_EQUIPMENT_ERROR_NOT_AUTHORIZED_FOR_CSG, "MM_MOBILE_EQUIPMENT_ERROR_NOT_AUTHORIZED_FOR_CSG", "NotAuthorizedForCsg" },
        { MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES, "MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES", "InsufficientResources" },
        { MM_MOBILE_EQUIPMENT_ERROR_MISSING_OR_UNKNOWN_APN, "MM_MOBILE_EQUIPMENT_ERROR_MISSING_OR_UNKNOWN_APN", "MissingOrUnknownApn" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN_PDP_ADDRESS_OR_TYPE, "MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN_PDP_ADDRESS_OR_TYPE", "UnknownPdpAddressOrType" },
        { MM_MOBILE_EQUIPMENT_ERROR_USER_AUTHENTICATION_FAILED, "MM_MOBILE_EQUIPMENT_ERROR_USER_AUTHENTICATION_FAILED", "UserAuthenticationFailed" },
        { MM_MOBILE_EQUIPMENT_ERROR_ACTIVATION_REJECTED_BY_GGSN_OR_GW, "MM_MOBILE_EQUIPMENT_ERROR_ACTIVATION_REJECTED_BY_GGSN_OR_GW", "ActivationRejectedByGgsnOrGw" },
        { MM_MOBILE_EQUIPMENT_ERROR_ACTIVATION_REJECTED_UNSPECIFIED, "MM_MOBILE_EQUIPMENT_ERROR_ACTIVATION_REJECTED_UNSPECIFIED", "ActivationRejectedUnspecified" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_SUPPORTED", "ServiceOptionNotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_SUBSCRIBED, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_SUBSCRIBED", "ServiceOptionNotSubscribed" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_OUT_OF_ORDER, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_OUT_OF_ORDER", "ServiceOptionOutOfOrder" },
        { MM_MOBILE_EQUIPMENT_ERROR_NSAPI_OR_PTI_ALREADY_IN_USE, "MM_MOBILE_EQUIPMENT_ERROR_NSAPI_OR_PTI_ALREADY_IN_USE", "NsapiOrPtiAlreadyInUse" },
        { MM_MOBILE_EQUIPMENT_ERROR_REGULAR_DEACTIVATION, "MM_MOBILE_EQUIPMENT_ERROR_REGULAR_DEACTIVATION", "RegularDeactivation" },
        { MM_MOBILE_EQUIPMENT_ERROR_QOS_NOT_ACCEPTED, "MM_MOBILE_EQUIPMENT_ERROR_QOS_NOT_ACCEPTED", "QosNotAccepted" },
        { MM_MOBILE_EQUIPMENT_ERROR_CALL_CANNOT_BE_IDENTIFIED, "MM_MOBILE_EQUIPMENT_ERROR_CALL_CANNOT_BE_IDENTIFIED", "CallCannotBeIdentified" },
        { MM_MOBILE_EQUIPMENT_ERROR_CS_SERVICE_TEMPORARILY_UNAVAILABLE, "MM_MOBILE_EQUIPMENT_ERROR_CS_SERVICE_TEMPORARILY_UNAVAILABLE", "CsServiceTemporarilyUnavailable" },
        { MM_MOBILE_EQUIPMENT_ERROR_FEATURE_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_FEATURE_NOT_SUPPORTED", "FeatureNotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERROR_IN_TFT_OPERATION, "MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERROR_IN_TFT_OPERATION", "SemanticErrorInTftOperation" },
        { MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_TFT_OPERATION, "MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_TFT_OPERATION", "SyntacticalErrorInTftOperation" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN_PDP_CONTEXT, "MM_MOBILE_EQUIPMENT_ERROR_UNKNOWN_PDP_CONTEXT", "UnknownPdpContext" },
        { MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERRORS_IN_PACKET_FILTER, "MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERRORS_IN_PACKET_FILTER", "SemanticErrorsInPacketFilter" },
        { MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_PACKET_FILTER, "MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_PACKET_FILTER", "SyntacticalErrorsInPacketFilter" },
        { MM_MOBILE_EQUIPMENT_ERROR_PDP_CONTEXT_WITHOUT_TFT_ALREADY_ACTIVATED, "MM_MOBILE_EQUIPMENT_ERROR_PDP_CONTEXT_WITHOUT_TFT_ALREADY_ACTIVATED", "PdpContextWithoutTftAlreadyActivated" },
        { MM_MOBILE_EQUIPMENT_ERROR_MULTICAST_GROUP_MEMBERSHIP_TIMEOUT, "MM_MOBILE_EQUIPMENT_ERROR_MULTICAST_GROUP_MEMBERSHIP_TIMEOUT", "MulticastGroupMembershipTimeout" },
        { MM_MOBILE_EQUIPMENT_ERROR_GPRS_UNKNOWN, "MM_MOBILE_EQUIPMENT_ERROR_GPRS_UNKNOWN", "GprsUnknown" },
        { MM_MOBILE_EQUIPMENT_ERROR_PDP_AUTH_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_PDP_AUTH_FAILURE", "PdpAuthFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_MOBILE_CLASS, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_MOBILE_CLASS", "InvalidMobileClass" },
        { MM_MOBILE_EQUIPMENT_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED_LEGACY, "MM_MOBILE_EQUIPMENT_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED_LEGACY", "LastPdnDisconnectionNotAllowedLegacy" },
        { MM_MOBILE_EQUIPMENT_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_LAST_PDN_DISCONNECTION_NOT_ALLOWED", "LastPdnDisconnectionNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_SEMANTICALLY_INCORRECT_MESSAGE, "MM_MOBILE_EQUIPMENT_ERROR_SEMANTICALLY_INCORRECT_MESSAGE", "SemanticallyIncorrectMessage" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_MANDATORY_INFORMATION, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_MANDATORY_INFORMATION", "InvalidMandatoryInformation" },
        { MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_TYPE_NOT_IMPLEMENTED, "MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_TYPE_NOT_IMPLEMENTED", "MessageTypeNotImplemented" },
        { MM_MOBILE_EQUIPMENT_ERROR_CONDITIONAL_IE_ERROR, "MM_MOBILE_EQUIPMENT_ERROR_CONDITIONAL_IE_ERROR", "ConditionalIeError" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNSPECIFIED_PROTOCOL_ERROR, "MM_MOBILE_EQUIPMENT_ERROR_UNSPECIFIED_PROTOCOL_ERROR", "UnspecifiedProtocolError" },
        { MM_MOBILE_EQUIPMENT_ERROR_OPERATOR_DETERMINED_BARRING, "MM_MOBILE_EQUIPMENT_ERROR_OPERATOR_DETERMINED_BARRING", "OperatorDeterminedBarring" },
        { MM_MOBILE_EQUIPMENT_ERROR_MAXIMUM_NUMBER_OF_BEARERS_REACHED, "MM_MOBILE_EQUIPMENT_ERROR_MAXIMUM_NUMBER_OF_BEARERS_REACHED", "MaximumNumberOfBearersReached" },
        { MM_MOBILE_EQUIPMENT_ERROR_REQUESTED_APN_NOT_SUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_REQUESTED_APN_NOT_SUPPORTED", "RequestedApnNotSupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_REQUEST_REJECTED_BCM_VIOLATION, "MM_MOBILE_EQUIPMENT_ERROR_REQUEST_REJECTED_BCM_VIOLATION", "RequestRejectedBcmViolation" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNSUPPORTED_QCI_OR_5QI_VALUE, "MM_MOBILE_EQUIPMENT_ERROR_UNSUPPORTED_QCI_OR_5QI_VALUE", "UnsupportedQciOr5qiValue" },
        { MM_MOBILE_EQUIPMENT_ERROR_USER_DATA_VIA_CONTROL_PLANE_CONGESTED, "MM_MOBILE_EQUIPMENT_ERROR_USER_DATA_VIA_CONTROL_PLANE_CONGESTED", "UserDataViaControlPlaneCongested" },
        { MM_MOBILE_EQUIPMENT_ERROR_SMS_PROVIDED_VIA_GPRS_IN_ROUTING_AREA, "MM_MOBILE_EQUIPMENT_ERROR_SMS_PROVIDED_VIA_GPRS_IN_ROUTING_AREA", "SmsProvidedViaGprsInRoutingArea" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_PTI_VALUE, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_PTI_VALUE", "InvalidPtiValue" },
        { MM_MOBILE_EQUIPMENT_ERROR_NO_BEARER_ACTIVATED, "MM_MOBILE_EQUIPMENT_ERROR_NO_BEARER_ACTIVATED", "NoBearerActivated" },
        { MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE, "MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE", "MessageNotCompatibleWithProtocolState" },
        { MM_MOBILE_EQUIPMENT_ERROR_RECOVERY_ON_TIMER_EXPIRY, "MM_MOBILE_EQUIPMENT_ERROR_RECOVERY_ON_TIMER_EXPIRY", "RecoveryOnTimerExpiry" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_TRANSACTION_ID_VALUE, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_TRANSACTION_ID_VALUE", "InvalidTransactionIdValue" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_AUTHORIZED_IN_PLMN, "MM_MOBILE_EQUIPMENT_ERROR_SERVICE_OPTION_NOT_AUTHORIZED_IN_PLMN", "ServiceOptionNotAuthorizedInPlmn" },
        { MM_MOBILE_EQUIPMENT_ERROR_NETWORK_FAILURE_ACTIVATION, "MM_MOBILE_EQUIPMENT_ERROR_NETWORK_FAILURE_ACTIVATION", "NetworkFailureActivation" },
        { MM_MOBILE_EQUIPMENT_ERROR_REACTIVATION_REQUESTED, "MM_MOBILE_EQUIPMENT_ERROR_REACTIVATION_REQUESTED", "ReactivationRequested" },
        { MM_MOBILE_EQUIPMENT_ERROR_IPV4_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_IPV4_ONLY_ALLOWED", "Ipv4OnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_IPV6_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_IPV6_ONLY_ALLOWED", "Ipv6OnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_SINGLE_ADDRESS_BEARERS_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_SINGLE_ADDRESS_BEARERS_ONLY_ALLOWED", "SingleAddressBearersOnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_COLLISION_WITH_NETWORK_INITIATED_REQUEST, "MM_MOBILE_EQUIPMENT_ERROR_COLLISION_WITH_NETWORK_INITIATED_REQUEST", "CollisionWithNetworkInitiatedRequest" },
        { MM_MOBILE_EQUIPMENT_ERROR_IPV4V6_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_IPV4V6_ONLY_ALLOWED", "Ipv4v6OnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_NON_IP_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_NON_IP_ONLY_ALLOWED", "NonIpOnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_BEARER_HANDLING_UNSUPPORTED, "MM_MOBILE_EQUIPMENT_ERROR_BEARER_HANDLING_UNSUPPORTED", "BearerHandlingUnsupported" },
        { MM_MOBILE_EQUIPMENT_ERROR_APN_RESTRICTION_INCOMPATIBLE, "MM_MOBILE_EQUIPMENT_ERROR_APN_RESTRICTION_INCOMPATIBLE", "ApnRestrictionIncompatible" },
        { MM_MOBILE_EQUIPMENT_ERROR_MULTIPLE_ACCESS_TO_PDN_CONNECTION_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_MULTIPLE_ACCESS_TO_PDN_CONNECTION_NOT_ALLOWED", "MultipleAccessToPdnConnectionNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_ESM_INFORMATION_NOT_RECEIVED, "MM_MOBILE_EQUIPMENT_ERROR_ESM_INFORMATION_NOT_RECEIVED", "EsmInformationNotReceived" },
        { MM_MOBILE_EQUIPMENT_ERROR_PDN_CONNECTION_NONEXISTENT, "MM_MOBILE_EQUIPMENT_ERROR_PDN_CONNECTION_NONEXISTENT", "PdnConnectionNonexistent" },
        { MM_MOBILE_EQUIPMENT_ERROR_MULTIPLE_PDN_CONNECTION_SAME_APN_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_MULTIPLE_PDN_CONNECTION_SAME_APN_NOT_ALLOWED", "MultiplePdnConnectionSameApnNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_SEVERE_NETWORK_FAILURE, "MM_MOBILE_EQUIPMENT_ERROR_SEVERE_NETWORK_FAILURE", "SevereNetworkFailure" },
        { MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES_FOR_SLICE_AND_DNN, "MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES_FOR_SLICE_AND_DNN", "InsufficientResourcesForSliceAndDnn" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNSUPPORTED_SSC_MODE, "MM_MOBILE_EQUIPMENT_ERROR_UNSUPPORTED_SSC_MODE", "UnsupportedSscMode" },
        { MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES_FOR_SLICE, "MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_RESOURCES_FOR_SLICE", "InsufficientResourcesForSlice" },
        { MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_TYPE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE, "MM_MOBILE_EQUIPMENT_ERROR_MESSAGE_TYPE_NOT_COMPATIBLE_WITH_PROTOCOL_STATE", "MessageTypeNotCompatibleWithProtocolState" },
        { MM_MOBILE_EQUIPMENT_ERROR_IE_NOT_IMPLEMENTED, "MM_MOBILE_EQUIPMENT_ERROR_IE_NOT_IMPLEMENTED", "IeNotImplemented" },
        { MM_MOBILE_EQUIPMENT_ERROR_N1_MODE_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_N1_MODE_NOT_ALLOWED", "N1ModeNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_RESTRICTED_SERVICE_AREA, "MM_MOBILE_EQUIPMENT_ERROR_RESTRICTED_SERVICE_AREA", "RestrictedServiceArea" },
        { MM_MOBILE_EQUIPMENT_ERROR_LADN_UNAVAILABLE, "MM_MOBILE_EQUIPMENT_ERROR_LADN_UNAVAILABLE", "LadnUnavailable" },
        { MM_MOBILE_EQUIPMENT_ERROR_MISSING_OR_UNKNOWN_DNN_IN_SLICE, "MM_MOBILE_EQUIPMENT_ERROR_MISSING_OR_UNKNOWN_DNN_IN_SLICE", "MissingOrUnknownDnnInSlice" },
        { MM_MOBILE_EQUIPMENT_ERROR_NGKSI_ALREADY_IN_USE, "MM_MOBILE_EQUIPMENT_ERROR_NGKSI_ALREADY_IN_USE", "NkgsiAlreadyInUse" },
        { MM_MOBILE_EQUIPMENT_ERROR_PAYLOAD_NOT_FORWARDED, "MM_MOBILE_EQUIPMENT_ERROR_PAYLOAD_NOT_FORWARDED", "PayloadNotForwarded" },
        { MM_MOBILE_EQUIPMENT_ERROR_NON_3GPP_ACCESS_TO_5GCN_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_NON_3GPP_ACCESS_TO_5GCN_NOT_ALLOWED", "Non3gppAccessTo5gcnNotAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_SERVING_NETWORK_NOT_AUTHORIZED, "MM_MOBILE_EQUIPMENT_ERROR_SERVING_NETWORK_NOT_AUTHORIZED", "ServingNetworkNotAuthorized" },
        { MM_MOBILE_EQUIPMENT_ERROR_DNN_NOT_SUPPORTED_IN_SLICE, "MM_MOBILE_EQUIPMENT_ERROR_DNN_NOT_SUPPORTED_IN_SLICE", "DnnNotSupportedInSlice" },
        { MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_USER_PLANE_RESOURCES_FOR_PDU_SESSION, "MM_MOBILE_EQUIPMENT_ERROR_INSUFFICIENT_USER_PLANE_RESOURCES_FOR_PDU_SESSION", "InsufficientUserPlaneResourcesForPduSession" },
        { MM_MOBILE_EQUIPMENT_ERROR_OUT_OF_LADN_SERVICE_AREA, "MM_MOBILE_EQUIPMENT_ERROR_OUT_OF_LADN_SERVICE_AREA", "OutOfLadnServiceArea" },
        { MM_MOBILE_EQUIPMENT_ERROR_PTI_MISMATCH, "MM_MOBILE_EQUIPMENT_ERROR_PTI_MISMATCH", "PtiMismatch" },
        { MM_MOBILE_EQUIPMENT_ERROR_MAX_DATA_RATE_FOR_USER_PLANE_INTEGRITY_TOO_LOW, "MM_MOBILE_EQUIPMENT_ERROR_MAX_DATA_RATE_FOR_USER_PLANE_INTEGRITY_TOO_LOW", "MaxDataRateForUserPlaneIntegrityTooLow" },
        { MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERROR_IN_QOS_OPERATION, "MM_MOBILE_EQUIPMENT_ERROR_SEMANTIC_ERROR_IN_QOS_OPERATION", "SemanticErrorInQosOperation" },
        { MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_QOS_OPERATION, "MM_MOBILE_EQUIPMENT_ERROR_SYNTACTICAL_ERROR_IN_QOS_OPERATION", "SyntacticalErrorInQosOperation" },
        { MM_MOBILE_EQUIPMENT_ERROR_INVALID_MAPPED_EPS_BEARER_IDENTITY, "MM_MOBILE_EQUIPMENT_ERROR_INVALID_MAPPED_EPS_BEARER_IDENTITY", "InvalidMappedEpsBearerIdentity" },
        { MM_MOBILE_EQUIPMENT_ERROR_REDIRECTION_TO_5GCN_REQUIRED, "MM_MOBILE_EQUIPMENT_ERROR_REDIRECTION_TO_5GCN_REQUIRED", "RedirectionTo5gcnRequired" },
        { MM_MOBILE_EQUIPMENT_ERROR_REDIRECTION_TO_EPC_REQUIRED, "MM_MOBILE_EQUIPMENT_ERROR_REDIRECTION_TO_EPC_REQUIRED", "RedirectionToEpcRequired" },
        { MM_MOBILE_EQUIPMENT_ERROR_TEMPORARILY_UNAUTHORIZED_FOR_SNPN, "MM_MOBILE_EQUIPMENT_ERROR_TEMPORARILY_UNAUTHORIZED_FOR_SNPN", "TemporarilyUnauthorizedForSnpn" },
        { MM_MOBILE_EQUIPMENT_ERROR_PERMANENTLY_UNAUTHORIZED_FOR_SNPN, "MM_MOBILE_EQUIPMENT_ERROR_PERMANENTLY_UNAUTHORIZED_FOR_SNPN", "PermanentlyUnauthorizedForSnpn" },
        { MM_MOBILE_EQUIPMENT_ERROR_ETHERNET_ONLY_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_ETHERNET_ONLY_ALLOWED", "EthernetOnlyAllowed" },
        { MM_MOBILE_EQUIPMENT_ERROR_UNAUTHORIZED_FOR_CAG, "MM_MOBILE_EQUIPMENT_ERROR_UNAUTHORIZED_FOR_CAG", "UnauthorizedForCag" },
        { MM_MOBILE_EQUIPMENT_ERROR_NO_NETWORK_SLICES_AVAILABLE, "MM_MOBILE_EQUIPMENT_ERROR_NO_NETWORK_SLICES_AVAILABLE", "NoNetworkSlicesAvailable" },
        { MM_MOBILE_EQUIPMENT_ERROR_WIRELINE_ACCESS_AREA_NOT_ALLOWED, "MM_MOBILE_EQUIPMENT_ERROR_WIRELINE_ACCESS_AREA_NOT_ALLOWED", "WirelineAccessAreaNotAllowed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMMobileEquipmentError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_connection_error_quark() implemented in mm-errors-quarks.c */

GType
mm_connection_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_CONNECTION_ERROR_UNKNOWN, "MM_CONNECTION_ERROR_UNKNOWN", "Unknown" },
        { MM_CONNECTION_ERROR_NO_CARRIER, "MM_CONNECTION_ERROR_NO_CARRIER", "NoCarrier" },
        { MM_CONNECTION_ERROR_NO_DIALTONE, "MM_CONNECTION_ERROR_NO_DIALTONE", "NoDialtone" },
        { MM_CONNECTION_ERROR_BUSY, "MM_CONNECTION_ERROR_BUSY", "Busy" },
        { MM_CONNECTION_ERROR_NO_ANSWER, "MM_CONNECTION_ERROR_NO_ANSWER", "NoAnswer" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMConnectionError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_serial_error_quark() implemented in mm-errors-quarks.c */

GType
mm_serial_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_SERIAL_ERROR_UNKNOWN, "MM_SERIAL_ERROR_UNKNOWN", "Unknown" },
        { MM_SERIAL_ERROR_OPEN_FAILED, "MM_SERIAL_ERROR_OPEN_FAILED", "OpenFailed" },
        { MM_SERIAL_ERROR_SEND_FAILED, "MM_SERIAL_ERROR_SEND_FAILED", "SendFailed" },
        { MM_SERIAL_ERROR_RESPONSE_TIMEOUT, "MM_SERIAL_ERROR_RESPONSE_TIMEOUT", "ResponseTimeout" },
        { MM_SERIAL_ERROR_OPEN_FAILED_NO_DEVICE, "MM_SERIAL_ERROR_OPEN_FAILED_NO_DEVICE", "OpenFailedNoDevice" },
        { MM_SERIAL_ERROR_FLASH_FAILED, "MM_SERIAL_ERROR_FLASH_FAILED", "FlashFailed" },
        { MM_SERIAL_ERROR_NOT_OPEN, "MM_SERIAL_ERROR_NOT_OPEN", "NotOpen" },
        { MM_SERIAL_ERROR_PARSE_FAILED, "MM_SERIAL_ERROR_PARSE_FAILED", "ParseFailed" },
        { MM_SERIAL_ERROR_FRAME_NOT_FOUND, "MM_SERIAL_ERROR_FRAME_NOT_FOUND", "FrameNotFound" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMSerialError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_message_error_quark() implemented in mm-errors-quarks.c */

GType
mm_message_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_MESSAGE_ERROR_ME_FAILURE, "MM_MESSAGE_ERROR_ME_FAILURE", "MeFailure" },
        { MM_MESSAGE_ERROR_SMS_SERVICE_RESERVED, "MM_MESSAGE_ERROR_SMS_SERVICE_RESERVED", "SmsServiceReserved" },
        { MM_MESSAGE_ERROR_NOT_ALLOWED, "MM_MESSAGE_ERROR_NOT_ALLOWED", "NotAllowed" },
        { MM_MESSAGE_ERROR_NOT_SUPPORTED, "MM_MESSAGE_ERROR_NOT_SUPPORTED", "NotSupported" },
        { MM_MESSAGE_ERROR_INVALID_PDU_PARAMETER, "MM_MESSAGE_ERROR_INVALID_PDU_PARAMETER", "InvalidPduParameter" },
        { MM_MESSAGE_ERROR_INVALID_TEXT_PARAMETER, "MM_MESSAGE_ERROR_INVALID_TEXT_PARAMETER", "InvalidTextParameter" },
        { MM_MESSAGE_ERROR_SIM_NOT_INSERTED, "MM_MESSAGE_ERROR_SIM_NOT_INSERTED", "SimNotInserted" },
        { MM_MESSAGE_ERROR_SIM_PIN, "MM_MESSAGE_ERROR_SIM_PIN", "SimPin" },
        { MM_MESSAGE_ERROR_PH_SIM_PIN, "MM_MESSAGE_ERROR_PH_SIM_PIN", "PhSimPin" },
        { MM_MESSAGE_ERROR_SIM_FAILURE, "MM_MESSAGE_ERROR_SIM_FAILURE", "SimFailure" },
        { MM_MESSAGE_ERROR_SIM_BUSY, "MM_MESSAGE_ERROR_SIM_BUSY", "SimBusy" },
        { MM_MESSAGE_ERROR_SIM_WRONG, "MM_MESSAGE_ERROR_SIM_WRONG", "SimWrong" },
        { MM_MESSAGE_ERROR_SIM_PUK, "MM_MESSAGE_ERROR_SIM_PUK", "SimPuk" },
        { MM_MESSAGE_ERROR_SIM_PIN2, "MM_MESSAGE_ERROR_SIM_PIN2", "SimPin2" },
        { MM_MESSAGE_ERROR_SIM_PUK2, "MM_MESSAGE_ERROR_SIM_PUK2", "SimPuk2" },
        { MM_MESSAGE_ERROR_MEMORY_FAILURE, "MM_MESSAGE_ERROR_MEMORY_FAILURE", "MemoryFailure" },
        { MM_MESSAGE_ERROR_INVALID_INDEX, "MM_MESSAGE_ERROR_INVALID_INDEX", "InvalidIndex" },
        { MM_MESSAGE_ERROR_MEMORY_FULL, "MM_MESSAGE_ERROR_MEMORY_FULL", "MemoryFull" },
        { MM_MESSAGE_ERROR_SMSC_ADDRESS_UNKNOWN, "MM_MESSAGE_ERROR_SMSC_ADDRESS_UNKNOWN", "SmscAddressUnknown" },
        { MM_MESSAGE_ERROR_NO_NETWORK, "MM_MESSAGE_ERROR_NO_NETWORK", "NoNetwork" },
        { MM_MESSAGE_ERROR_NETWORK_TIMEOUT, "MM_MESSAGE_ERROR_NETWORK_TIMEOUT", "NetworkTimeout" },
        { MM_MESSAGE_ERROR_NO_CNMA_ACK_EXPECTED, "MM_MESSAGE_ERROR_NO_CNMA_ACK_EXPECTED", "NoCnmaAckExpected" },
        { MM_MESSAGE_ERROR_UNKNOWN, "MM_MESSAGE_ERROR_UNKNOWN", "Unknown" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMMessageError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_cdma_activation_error_quark() implemented in mm-errors-quarks.c */

GType
mm_cdma_activation_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_CDMA_ACTIVATION_ERROR_NONE, "MM_CDMA_ACTIVATION_ERROR_NONE", "None" },
        { MM_CDMA_ACTIVATION_ERROR_UNKNOWN, "MM_CDMA_ACTIVATION_ERROR_UNKNOWN", "Unknown" },
        { MM_CDMA_ACTIVATION_ERROR_ROAMING, "MM_CDMA_ACTIVATION_ERROR_ROAMING", "Roaming" },
        { MM_CDMA_ACTIVATION_ERROR_WRONG_RADIO_INTERFACE, "MM_CDMA_ACTIVATION_ERROR_WRONG_RADIO_INTERFACE", "WrongRadioInterface" },
        { MM_CDMA_ACTIVATION_ERROR_COULD_NOT_CONNECT, "MM_CDMA_ACTIVATION_ERROR_COULD_NOT_CONNECT", "CouldNotConnect" },
        { MM_CDMA_ACTIVATION_ERROR_SECURITY_AUTHENTICATION_FAILED, "MM_CDMA_ACTIVATION_ERROR_SECURITY_AUTHENTICATION_FAILED", "SecurityAuthenticationFailed" },
        { MM_CDMA_ACTIVATION_ERROR_PROVISIONING_FAILED, "MM_CDMA_ACTIVATION_ERROR_PROVISIONING_FAILED", "ProvisioningFailed" },
        { MM_CDMA_ACTIVATION_ERROR_NO_SIGNAL, "MM_CDMA_ACTIVATION_ERROR_NO_SIGNAL", "NoSignal" },
        { MM_CDMA_ACTIVATION_ERROR_TIMED_OUT, "MM_CDMA_ACTIVATION_ERROR_TIMED_OUT", "TimedOut" },
        { MM_CDMA_ACTIVATION_ERROR_START_FAILED, "MM_CDMA_ACTIVATION_ERROR_START_FAILED", "StartFailed" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMCdmaActivationError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* mm_carrier_lock_error_quark() implemented in mm-errors-quarks.c */

GType
mm_carrier_lock_error_get_type (void)
{
  static gsize g_define_type_id_initialized = 0;

  if (g_once_init_enter (&g_define_type_id_initialized))
    {
      static const GEnumValue values[] = {
        { MM_CARRIER_LOCK_ERROR_UNKNOWN, "MM_CARRIER_LOCK_ERROR_UNKNOWN", "Unknown" },
        { MM_CARRIER_LOCK_ERROR_INVALID_SIGNATURE, "MM_CARRIER_LOCK_ERROR_INVALID_SIGNATURE", "InvalidSignature" },
        { MM_CARRIER_LOCK_ERROR_INVALID_IMEI, "MM_CARRIER_LOCK_ERROR_INVALID_IMEI", "InvalidImei" },
        { MM_CARRIER_LOCK_ERROR_INVALID_TIMESTAMP, "MM_CARRIER_LOCK_ERROR_INVALID_TIMESTAMP", "InvalidTimestamp" },
        { MM_CARRIER_LOCK_ERROR_NETWORK_LIST_TOO_LARGE, "MM_CARRIER_LOCK_ERROR_NETWORK_LIST_TOO_LARGE", "NetworkListTooLarge" },
        { MM_CARRIER_LOCK_ERROR_SIGNATURE_ALGORITHM_NOT_SUPPORTED, "MM_CARRIER_LOCK_ERROR_SIGNATURE_ALGORITHM_NOT_SUPPORTED", "SignatureAlgorithmNotSupported" },
        { MM_CARRIER_LOCK_ERROR_FEATURE_NOT_SUPPORTED, "MM_CARRIER_LOCK_ERROR_FEATURE_NOT_SUPPORTED", "FeatureNotSupported" },
        { MM_CARRIER_LOCK_ERROR_DECODE_OR_PARSING_ERROR, "MM_CARRIER_LOCK_ERROR_DECODE_OR_PARSING_ERROR", "DecodeOrParsingError" },
        { 0, NULL, NULL }
      };
      GType g_define_type_id =
        g_enum_register_static (g_intern_static_string ("MMCarrierLockError"), values);
      g_once_init_leave (&g_define_type_id_initialized, g_define_type_id);
    }

  return g_define_type_id_initialized;
}

/* Generated data ends here */

